@@ -2,10 +2,10 @@ use bevy::prelude::*;
 use bevy_kira_audio::{Audio, AudioPlugin};
 
 fn main() {
-    App::build()
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(AudioPlugin)
-        .add_startup_system(load_audio.system())
+        .add_startup_system(load_audio)
         .run();
 }
 
